Schema
======

The **common schema for IC design data** ensures that different modules of ORDeC speak the same language and can interact seamlessly.

.. automodule:: ordec.schema
   :member-order: bysource
   :members: 
   :undoc-members:
   :exclude-members: check_integrity

.. .. automodule:: ordec.schema
..   :members:
